==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/RevisionDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "approvedby",
    "approvedate",
    "requestedby",
    "daterequested",
    "revisionreason"
})
@XmlRootElement(name = "RevisionDetails")
public class RevisionDetails {

    @XmlElement(name = "APPROVEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type approvedby;
    @XmlElement(name = "APPROVEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME approvedate;
    @XmlElement(name = "REQUESTEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type requestedby;
    @XmlElement(name = "DATEREQUESTED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME daterequested;
    @XmlElement(name = "REVISIONREASON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String revisionreason;

    /**
     * Obtient la valeur de la propriété approvedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVEDBY() {
        return approvedby;
    }

    /**
     * Définit la valeur de la propriété approvedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVEDBY(USERID_Type value) {
        this.approvedby = value;
    }

    /**
     * Obtient la valeur de la propriété approvedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Définit la valeur de la propriété approvedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Obtient la valeur de la propriété requestedby.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getREQUESTEDBY() {
        return requestedby;
    }

    /**
     * Définit la valeur de la propriété requestedby.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setREQUESTEDBY(PERSONID_Type value) {
        this.requestedby = value;
    }

    /**
     * Obtient la valeur de la propriété daterequested.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Définit la valeur de la propriété daterequested.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Obtient la valeur de la propriété revisionreason.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Définit la valeur de la propriété revisionreason.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

}

==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/RevisionDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUESTED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONREASON" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "approvedby",
    "approvedate",
    "requestby",
    "daterequested",
    "revisionreason"
})
@XmlRootElement(name = "RevisionDetails")
public class RevisionDetails {

    @XmlElement(name = "APPROVEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type approvedby;
    @XmlElement(name = "APPROVEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME approvedate;
    @XmlElement(name = "REQUESTBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type requestby;
    @XmlElement(name = "DATEREQUESTED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME daterequested;
    @XmlElement(name = "REVISIONREASON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String revisionreason;

    /**
     * Obtient la valeur de la propriété approvedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVEDBY() {
        return approvedby;
    }

    /**
     * Définit la valeur de la propriété approvedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVEDBY(USERID_Type value) {
        this.approvedby = value;
    }

    /**
     * Obtient la valeur de la propriété approvedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Définit la valeur de la propriété approvedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Obtient la valeur de la propriété requestby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getREQUESTBY() {
        return requestby;
    }

    /**
     * Définit la valeur de la propriété requestby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setREQUESTBY(USERID_Type value) {
        this.requestby = value;
    }

    /**
     * Obtient la valeur de la propriété daterequested.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUESTED() {
        return daterequested;
    }

    /**
     * Définit la valeur de la propriété daterequested.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUESTED(DATETIME value) {
        this.daterequested = value;
    }

    /**
     * Obtient la valeur de la propriété revisionreason.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREVISIONREASON() {
        return revisionreason;
    }

    /**
     * Définit la valeur de la propriété revisionreason.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREVISIONREASON(String value) {
        this.revisionreason = value;
    }

}
